/**
    (C) Copyright 2012 Dominik Wagenfuehr

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BOT_HH
#define BOT_HH

#include <string>

class Bot
{
  public:
    /// Konstruktor.
    /**
     * Setzt die Standardstrategie auf "accept".
     */
    Bot();

    /// Setzt die Strategie fuer einen Bot.
    /**
     * Die Strategie bestimmt, wie der Bot sich verhaelt und
     * anbietet bzw. wann er Angebote annimmt/ablehnt.
     * Moegliche Werte sind:
     * "accept" - Jedes Angebot wird akzeptiert.
     * "decline" - Jedes Angebot wird abgelehnt.
     * "variable" - Es wird je nach Wert entschieden, ob
     * angenommen oder abgelehnt wird.
     * @param strategy Die gewuenschte Strategie.
     * @return true, wenn die Strategie bekannt ist und gesetzt wurde
     */
    bool setStrategy( const std::string& strategy );

    /// Akzeptiert oder lehnt ein Angebot ab.
    /**
     * Diese Methode berechnet anhand der Strategie, ob der Wert
     * angenommen oder abgelehnt wird. Der angebotene Wert
     * muss zwischen 0 und 1000 liegen.
     * @param value Der angebotene Wert.
     * @return true, wenn das Angebot akzeptiert wurde, ansonsten false
     */
    bool acceptOffer( const int value );

    /// Gibt die gesammelten Punkte zurueck.
    int getPoints() const;

  private:
    /// Die zu verwendende Strategie bei jedem Spiel.
    std::string mStrategy;

    /// Anzahl der nacheinander angenommenen Angebote.
    int mNumAcceptInRow;

    /// Anzahl der nacheinander abgelehnten Angebote.
    int mNumDeclineInRow;

    /// Gesammelte Punkte.
    int mPoints;
};

#endif // BOT_HH
